==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/bigup/lang/bigup_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Cancel',
	'bouton_enlever' => 'Remove',

	// C
	'cfg_charger_public' => 'Script in the public website',
	'cfg_charger_public_case' => 'Load scripts in the public website',
	'cfg_client_height' => 'Height',
	'cfg_client_height_explication' => 'Maximum image height (px) Hauteur maximale de l’image (px)',
	'cfg_client_quality' => 'Quality',
	'cfg_client_quality_explication' => 'Image compression after resizing, value between 0 and 100, default: 85',
	'cfg_client_width' => 'Width',
	'cfg_client_width_explication' => 'Maximum image width (px) ',
	'cfg_explication_parametrages' => 'These options target only the file fields managed by drag and drop.',
	'cfg_explication_retailler_image' => 'If width and/or height are entered, the images will be resized by the browser before being sent to the server',
	'cfg_max_file_size' => 'Maximum file size',
	'cfg_max_file_size_explication' => 'Maximum file size (in Mio).',
	'cfg_titre_parametrages' => 'File Upload',
	'cfg_titre_retailler_image' => 'Enable image resizing by the browser',
	'cfg_titre_retailler_image_actif' => 'Browser-based image resizing is enabled with the following values',
	'choisir' => 'Choose',

	// D
	'deposer_la_vignette_ici' => 'Drop the thumbnail here',
	'deposer_le_logo_ici' => 'Drop the LOGO here',
	'deposer_vos_fichiers_ici' => 'Drop your files here',
	'deposer_votre_fichier_ici' => 'Drop your file here',

	// E
	'erreur_de_transfert' => 'Upload error',
	'erreur_probleme_survenu' => 'A problem occurred…',
	'erreur_taille_max' => 'Maximum file size is @taille@',
	'erreur_type_fichier' => 'Wrong file type!',

	// F
	'fichier_efface' => 'File deleted',

	// O
	'ou' => 'or',

	// S
	'selectionner' => 'Select',
	'succes_fichier_envoye' => 'File has been sent',
	'succes_logo_envoye' => 'Logo has been sent',
	'succes_vignette_envoyee' => 'Thumbnail has been sent',

	// T
	'televerser' => 'Upload',
	'titre_page_configurer_bigup' => 'Big Upload Configuration',

	// Z
	'zbug_necessite_plugin' => 'The <code>@balise@</code> tag requires the plugin <code>@plugin@</code>'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/bigup/lang/bigup_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Cancel',
	'bouton_enlever' => 'Remove',

	// C
	'cfg_charger_public' => 'Script in the public website',
	'cfg_charger_public_case' => 'Load scripts in the public website',
	'cfg_client_height' => 'Height',
	'cfg_client_height_explication' => 'Maximum image height (px) Hauteur maximale de l’image (px)',
	'cfg_client_quality' => 'Quality',
	'cfg_client_quality_explication' => 'Image compression after resizing, value between 0 and 100, default: 85',
	'cfg_client_width' => 'Width',
	'cfg_client_width_explication' => 'Maximum image width (px) ',
	'cfg_explication_parametrages' => 'These options target only the file fields managed by drag and drop.',
	'cfg_explication_retailler_image' => 'If width and/or height are entered, the images will be resized by the browser before being sent to the server',
	'cfg_max_file_size' => 'Maximum file size',
	'cfg_max_file_size_explication' => 'Maximum file size (in MiB).',
	'cfg_titre_parametrages' => 'File Upload',
	'cfg_titre_retailler_image' => 'Enable image resizing by the browser',
	'cfg_titre_retailler_image_actif' => 'Browser-based image resizing is enabled with the following values',
	'choisir' => 'Choose',

	// D
	'deposer_la_vignette_ici' => 'Drop the thumbnail here',
	'deposer_le_logo_ici' => 'Drop the LOGO here',
	'deposer_vos_fichiers_ici' => 'Drop your files here',
	'deposer_votre_fichier_ici' => 'Drop your file here',

	// E
	'erreur_de_transfert' => 'Upload error',
	'erreur_probleme_survenu' => 'A problem occurred…',
	'erreur_taille_max' => 'Maximum file size is @taille@',
	'erreur_type_fichier' => 'Wrong file type!',

	// F
	'fichier_efface' => 'File deleted',

	// O
	'ou' => 'or',

	// S
	'selectionner' => 'Select',
	'succes_fichier_envoye' => 'File has been sent',
	'succes_logo_envoye' => 'Logo has been sent',
	'succes_vignette_envoyee' => 'Thumbnail has been sent',

	// T
	'televerser' => 'Upload',
	'titre_page_configurer_bigup' => 'Big Upload Configuration',

	// Z
	'zbug_necessite_plugin' => 'The <code>@balise@</code> tag requires the plugin <code>@plugin@</code>',
];
